
# Requirements
 - VSL Synchron Strings I
 - Dorico 3
 
# Contents
This installation consists of the following files:

* `synstrings.doricolib`
* `SynViolins1.vsynpreset`
* `SynViolins2.vsynpreset`
* `SynViolas.vsynpreset`
* `SynCellos.vsynpreset`
* `SynBasses.vsynpreset`

The doricolib file works with all the Synchron Player presets. Installation:

* The Dorico expression map is installed by importing `synchron-strings.doricolib` 
from the Dorico expression map panel. 
The import will create an expression map named _SynStrings_.
* The Synchron Player presets are installed by by moving or copying them to your VSL User Preset folder.
(You can find that folder by looking in the Synchron Player preferences.)

# What's new

This is a complete rewrite from the previous versions and contains several enhancements:

* The previous expression map sent five or six extra MIDI messages per note; this one sends only two. 
* You can use the Dorico automation lanes to control the level of vibrato using CC 1. 
* You can use the Dorico automation lanes to control the degree of marcato using CC 20. 
* The _sforzato_ (_sfz_) patch is now supported. 
* The mutual-exclusion groups have been reorganized somewhat to make them more consistent with other VSL instruments.
* I probably added a few new bugs. :-) Let me know.

What playing techniques are supported?

* Techniques: _natural_, _tremolo_, _pizzicato_, _snap (Bartok) pizzicato_, _half-step
  trills_, _full-step trills_, _cantabile_, _flautando_
* Length articulations: _natural_, _staccato_, _staccatissimo_, _tenuto_, _portato_
  (i.e., _tenuto-staccato_)
* Attacks: _normal attack_, _soft attack_, _marcato_, _sfz_
* Legato: _normal_, _legato_
* Vibrato: _regular vibrato_, _no vibrato_, _molto vibrato_. 

...and combinations of the above: pick one from each category. (Yes,
it's a pretty big expression map.)

# Notes

Dynamics notation is left entirely to Dorico. That includes explicit
markings such as _pp_, hairpins, accent marks (stressed and unstressed),
etc. You can, of course, also use the dynamics lane in the Dorico play tab.

The VSL Synchron Double Bass patches don't include _cantabile_ or _molto vibrato_
patches, so cantabile falls back to _soft attack_ and _molto vibrato_
falls back to _normal vibrato_.

The VSL patches don't provide _sfz_ for all articulations. This expression map falls back
to _marcato_ if _sfz_ is not available. E.g., a trill marked _sfz_ will be played as
a trill with _marcato_ attack.

All VSL patches are initially unloaded in this preset, so until you
enable them in the Synchron Player, you won’t hear anything. I suggest
setting “Enable slots on MIDI activity” in the Synchron Player
preferences so that they are loaded on demand.

_Molto vibrato_ corresponds to what VSL calls "lyrical vibrato". It doesn't just mean "more vibrato" ---
see [this thread](https://www.vsl.co.at/community/posts/t49000-crossfade-all-3-levels-of-vibrato#post274520)
on the VSL forum. In short, regular vibrato corresponds to the typical way a string player would play:
the louder the dynamic, the stronger the vibrato. In contrast, lyrical vibrato aims to be the maximum
amount of vibrato at all dynamics. This preset uses CC 1 to cross-fade between regular vibrato and no-vibrato, 
or between lyrical vibrato and non-vibrato. 
The cross-fading is done in the same way as the VSL-provided presets. 

# User-defined playing techniques 
The Dorico expression map uses three user-defined playing techniques:

* _Cantabile_ (`pt.user.cantabile`)
* _Molto Vibrato_ (`pt.user.molto_vibrato`)
* _Soft Attack_ (`pt.user.soft_attack`)

To use them, you will need to create user-defined playing techniques
and add music symbols for them. Here is one way to do that:

1. In Dorico, select the _Write_ tab.
2. Open the playing techniques panel on the right. 
3. In the Common area (or the Strings area if you prefer) press “+” to
  add a new music symbol.
4. In the pop-up panel, enter “cantabile” (lower case) for the name of
  the music symbol.
5. Click on “Edit” in the Playback playing-technique row.
6. In the resulting nested pop-up, click “+” to add a new playing
  technique.
7. Set the playing technique name to “Cantabile” (upper case this time).
   This creates a new playing technique `pt.user.cantabile`. (Dorico automatically
   converts "Cantabile" to `pt.user.cantabile`.)
8. Click OK. Now you’re back in the music-symbols panel.
9. In the “Playback playing technique” menu, choose the playing technique “Cantabile”,
  which you just added.
10. Click “OK” to install the new music symbol. 

Repeat these steps to add the playback playing technique _Molto Vibrato_ and music
symbol _molto vib._ Repeat again to add the playback playing technique
_Soft Attack_ and music symbol _soft attack_.

Now you should be able to use _molto vib._, _cantabile_, or _soft
attack_ to your score in the usual ways.

In the instructions above, you can change the music symbols
to whatever you like. E.g., you could use another name or a glyph.
What's important is that the playing technique associated with the music symbol
matches the expression map. For example, the expression map uses the playing
technique `pt.user.molto_vibrato` (which Dorico renders _Molto Vibrato_), so
you need to associate whatever music symbol you choose with that playing technique.

# History

### Version 0: 13 Dec 2019
Initial release; first violins only
### Version 1: 17 Dec 2019
First full release of all Synchron Strings
### Version 2: 28 Dec 2019
Bug fix: made "arco" work in expression map.
No change to VSL presets.
### Version 3: 24 Feb 2020
Major revision: fewer MIDI messages, automation-lane support, sfz.
### Version 4: 25 Feb 2020
Bug fix: dorico expression map ID corrected from xmap.user.woodwinds -> xmap.user.synstrings.
	
